@@ -10,7 +10,7 @@ from matsense.cmd import CMD
 from matsense.uclient import Uclient
 from matsense.process import Processor
 from matsense.tools import (
-	load_config, blank_config, check_config, make_action, DEST_SUFFIX
+	dump_config, load_config, blank_config, check_config, make_action, DEST_SUFFIX
 )
 
 N = 16
@@ -19,187 +19,150 @@ FPS = 194
 TH = 0.15
 UDP = False
 
-def print_paras(paras):
-	print(f"Server parameters:")
-	print(f"  initiating frame number: {paras[0]}")
-	print(f"  calibration window size: {paras[1]}")
-	print(f"  filter:  {paras[2]}")
-	my_filter = paras[2]
-	if my_filter == 0:
-		print(f"    None")
-	elif my_filter == 1:
-		print(f"    exponential smoothing")
-		print(f"    * ALPHA: {paras[3]}")
-		print(f"    * BETA:  {paras[4]}")
-	elif my_filter == 2:
-		print(f"    moving average")
-		print(f"    * kernel size: {paras[3]}")
-	elif my_filter == 3:
-		print(f"    sinc low-pass filter")
-		print(f"    * kernel size:       {paras[3]}")
-		print(f"    * cut-off frequency: {paras[4]}")
+interactive_commands = {
+	"close": CMD.CLOSE,
+	"data": CMD.DATA,
+	"raw": CMD.RAW,
+	"rec_data": CMD.REC_DATA,
+	"rec_raw": CMD.REC_RAW,
+	"rec_stop": CMD.REC_STOP,
+	"restart": CMD.RESTART,
+	"restart_file": CMD.RESTART_FILE,
+	"config": CMD.CONFIG,
+	"data_imu": CMD.DATA_IMU,
+}
 
-def interactive_cmd(my_client, my_cmd):
-	"""interactive command parser
+help_msg = {
+	"close": "close server",
+	"data": "get a data frame",
+	"raw": "get a raw data frame",
+	"rec_data": "send signal to record data",
+	"rec_raw": "send signal to record raw data",
+	"rec_stop": "stop recording",
+	"restart": "restart server, optional arg: configuration filename (relative to client path)",
+	"restart_file": "restart server with configuration filename (relative to server path)",
+	"config": "get server configuration",
+	"data_imu": "get an IMU data frame",
+}
 
-	Show hints to help input specific parameters.
-	
-	Args:
-		my_cmd (CMD): a predefined command
-	"""
-	if my_cmd not in CMD.__members__.values():
-		print("Unknown command!")
-		return
+def print_config(config):
+	config_str = dump_config(config)
+	print(config_str)
 
-	try:
-		if my_cmd == CMD.CLOSE:
-			my_client.send_cmd(my_cmd)
-		elif my_cmd in (CMD.DATA, CMD.RAW):
-			my_client.send_cmd(my_cmd)
-			frame_idx = my_client.recv_frame()[1]
-			print(f"frame_idx: {frame_idx}")
-		elif my_cmd in (CMD.REC_DATA, CMD.REC_RAW):
-			print(f"recording filename:")
-			my_filename = input("|> ").strip()
-			my_client.send_cmd(my_cmd, my_filename)
-			ret, recv_filename = my_client.recv_string()
-			if ret == 0:
-				if my_cmd == CMD.REC_DATA:
-					data_mode = "processed"
-				else:
-					data_mode = "raw"
-				print(f"recording {data_mode} data to file: {recv_filename}")
-			else:
-				print(f"fail to write to file: {recv_filename}")
-		elif my_cmd == CMD.REC_STOP:
-			my_client.send_cmd(my_cmd)
-			ret, recv_str = my_client.recv_string()
-			if ret == 0:
-				print("stop recording")
-			else:
-				print("fail to stop recording!")
-		elif my_cmd == CMD.RESTART:
-			try:
-				print(f"initiating frame number:")
-				obtained = input("|> ").strip()
-				if obtained:
-					my_initcali = int(obtained)
-				else:
-					my_initcali = -1
-				print(f"{my_initcali}")
-				print(f"calibration window size:")
-				obtained = input("|> ").strip()
-				if obtained:
-					my_win = int(obtained)
-				else:
-					my_win = -1
-				print(f"{my_win}")
-				print(f"filter:")
-				obtained = input("|> ").strip()
-				if obtained:
-					my_filter = int(obtained)
-				else:
-					my_filter = -1
-				print(f"{my_filter}")
-				args = [my_initcali, my_win, my_filter]
-				if my_filter == 1:
-					print(f"exponential smoothing.")
-					print(f"alpha:")
-					obtained = input("|> ").strip()
-					if obtained:
-						my_alpha = float(obtained)
-					else:
-						my_alpha = -1.0
-					print(f"{my_alpha}")
-					print(f"beta:")
-					obtained = input("|> ").strip()
-					if obtained:
-						my_beta = float(obtained)
-					else:
-						my_beta = -1.0
-					print(f"{my_beta}")
-					args.append(my_alpha)
-					args.append(my_beta)
-				elif my_filter == 2:
-					print(f"moving average.")
-					print(f"kernel size:")
-					obtained = input("|> ").strip()
-					if obtained:
-						my_ma_size = int(obtained)
-					else:
-						my_ma_size = -1
-					print(f"{my_ma_size}")
-					args.append(my_ma_size)
-				elif my_filter == 3:
-					print(f"sinc low-pass filter.")
-					print(f"kernel size:")
-					obtained = input("|> ").strip()
-					if obtained:
-						my_lp_size = int(obtained)
-					else:
-						my_lp_size = -1
-					print(f"{my_lp_size}")
-					print(f"cut-off frequency:")
-					obtained = input("|> ").strip()
-					if obtained:
-						my_lp_w = float(obtained)
-					else:
-						my_lp_w = -1.0
-					print(f"{my_lp_size}")
-					args.append(my_lp_size)
-					args.append(my_lp_w)
-
-				my_client.send_cmd(my_cmd, args=args)
-				results = my_client.recv_paras()
-				if results[0] == 0:
-					print(f"server restarting...")
-				else:
-					print("fail to restart server")
-				print_paras(results[1:])
-			except ValueError:
-				print("invalid arguments to restart server")
-		elif my_cmd == CMD.PARAS:
-			my_client.send_cmd(my_cmd)
-			results = my_client.recv_paras()
-			print_paras(results[1:])
-		elif my_cmd == CMD.REC_BREAK:
-			my_client.send_cmd(my_cmd)
-			ret, recv_str = my_client.recv_string()
-			if ret == 0:
-				print("successfully break")
-			else:
-				print("fail to break!")
-		elif my_cmd == CMD.DATA_IMU:
-			my_client.send_cmd(my_cmd)
-			data_imu, frame_idx = my_client.recv_imu()
-			print(f"IMU data: {data_imu}")
-			print(f"frame_idx: {frame_idx}")
-
-	except (FileNotFoundError, ConnectionResetError):
-		print("server off-line")
-	except ConnectionRefusedError:
-		print("server refused connection")
-	except timeout:
-		print("server no response")
+def print_help():
+	print("Usage: ")
+	for key, value in interactive_commands.items():
+		print(f"  {key} / {value}:  {help_msg[key]}")
+	print("Type 'help' to get this message.")
 
 def run_client_interactive(my_client):
+	print_help()
 	while True:
+		unknown = False
+
 		try:
 			data = input('>> ').strip()
-			if data and "quit".startswith(data) or data == "exit":
-				return
 		except (EOFError, KeyboardInterrupt):
 			return
 
-		try:
-			data = data.strip().split()
-			if not data:
-				raise Exception
-			my_cmd = int(data[0])
-		except:
+		if not data:
+			unknown = True
+		elif "quit".startswith(data) or data == "exit":
+			return
+		elif data == "help":
+			print_help()
+			continue
+		elif data in interactive_commands:
+			my_cmd = interactive_commands[data]
+		else:
+			try:
+				my_cmd = int(data)
+				if my_cmd not in CMD.__members__.values():
+					unknown = True
+			except:
+				unknown = True
+
+		if unknown:
+			print("Unknown command!")
 			continue
 
-		interactive_cmd(my_client, my_cmd)
+		try:
+			if my_cmd == CMD.CLOSE:
+				my_client.send_cmd(my_cmd)
+			elif my_cmd in (CMD.DATA, CMD.RAW):
+				my_client.send_cmd(my_cmd)
+				frame_idx = my_client.recv_frame()[1]
+				print(f"frame_idx: {frame_idx}")
+			elif my_cmd in (CMD.REC_DATA, CMD.REC_RAW):
+				print(f"recording filename:")
+				my_filename = input("|> ").strip()
+				my_client.send_cmd(my_cmd, my_filename)
+				ret, recv_filename = my_client.recv_string()
+				if ret == 0:
+					if my_cmd == CMD.REC_DATA:
+						data_mode = "processed"
+					else:
+						data_mode = "raw"
+					print(f"recording {data_mode} data to file: {recv_filename}")
+				else:
+					print(f"fail to write to file: {recv_filename}")
+			elif my_cmd == CMD.REC_STOP:
+				my_client.send_cmd(my_cmd)
+				ret, recv_str = my_client.recv_string()
+				if ret == 0:
+					print("stop recording")
+				else:
+					print("fail to stop recording!")
+			elif my_cmd == CMD.RESTART:
+				print("RESTART server")
+				print("client-side config filename:")
+				config_filename = input("|> ").strip()
+				if config_filename != "":
+					with open(config_filename, 'r', encoding='utf-8') as f:
+						config_str = f.read()
+				else:
+					config_str = ""
+				my_client.send_cmd(my_cmd, config_str)
+				ret, config = my_client.recv_config()
+				print("Received config:")
+				print_config(config)
+				if ret == 0:
+					print("server restarting...")
+				else:
+					print("server failted to restart")
+			elif my_cmd == CMD.RESTART_FILE:
+				print("RESTART server")
+				print("server-side config filename:")
+				config_filename = input("|> ").strip()
+				if config_filename == "":
+					print("must input filename!!!")
+				else:
+					my_client.send_cmd(my_cmd, config_filename)
+					ret, config = my_client.recv_config()
+					print("Received config:")
+					print_config(config)
+					if ret == 0:
+						print("server restarting...")
+					else:
+						print("server failted to restart")
+			elif my_cmd == CMD.CONFIG:
+				my_client.send_cmd(my_cmd)
+				ret, config = my_client.recv_config()
+				print("Received config:")
+				print_config(config)
+			elif my_cmd == CMD.DATA_IMU:
+				my_client.send_cmd(my_cmd)
+				data_imu, frame_idx = my_client.recv_imu()
+				print(f"IMU data: {data_imu}")
+				print(f"frame_idx: {frame_idx}")
+
+		except (FileNotFoundError, ConnectionResetError):
+			print("server off-line")
+		except ConnectionRefusedError:
+			print("server refused connection")
+		except timeout:
+			print("server no response")
+
 
 def prepare_config(args):
 	## load config and combine commandline arguments
@@ -226,8 +189,8 @@ def prepare_config(args):
 		config['visual']['zlim'] = args.zlim
 	if config['visual']['fps'] is None or hasattr(args, 'fps'+DEST_SUFFIX):
 		config['visual']['fps'] = args.fps
-	if config['visual']['pyqtgraph'] is None or hasattr(args, 'matplot'+DEST_SUFFIX):
-		config['visual']['pyqtgraph'] = not args.matplot
+	if config['visual']['pyqtgraph'] is None or hasattr(args, 'pyqtgraph'+DEST_SUFFIX):
+		config['visual']['pyqtgraph'] = args.pyqtgraph
 	if config['visual']['scatter'] is None or hasattr(args, 'scatter'+DEST_SUFFIX):
 		config['visual']['scatter'] = args.scatter
 	if config['visual']['show_value'] is None or hasattr(args, 'show_value'+DEST_SUFFIX):
@@ -236,12 +199,12 @@ def prepare_config(args):
 		config['client_mode']['raw'] = args.raw
 	if config['client_mode']['interactive'] is None or hasattr(args, 'interactive'+DEST_SUFFIX):
 		config['client_mode']['interactive'] = args.interactive
-	check_config(config)
 
 	## some modifications
 	if config['process']['interp'] is None:
 		config['process']['interp'] = copy.deepcopy(config['sensor']['shape'])
 
+	check_config(config)
 	return config
 
 
@@ -258,7 +221,8 @@ def main():
 	parser.add_argument('-i', '--interactive', dest='interactive', action=make_action('store_true'), default=False, help="interactive mode")
 	parser.add_argument('-z', '--zlim', dest='zlim', action=make_action('store'), default=ZLIM, type=float, help="z-axis limit")
 	parser.add_argument('-f', dest='fps', action=make_action('store'), default=FPS, type=int, help="frames per second")
-	parser.add_argument('-m', '--matplot', dest='matplot', action=make_action('store_true'), default=False, help="use mathplotlib to plot")
+	parser.add_argument('--pyqtgraph', dest='pyqtgraph', action=make_action('store_true'), default=False, help="use pyqtgraph to plot")
+	# parser.add_argument('-m', '--matplot', dest='matplot', action=make_action('store_true'), default=False, help="use mathplotlib to plot")
 	parser.add_argument('--config', dest='config', action=make_action('store'), default=None, help="specify configuration file")
 
 	parser.add_argument('--scatter', dest='scatter', action=make_action('store_true'), default=False, help="show scatter plot")
